NotificationCallBackDetails class

Constructors

NotificationCallBackDetails({required EventType eventType, required NotificationMessage message, required String? argrument, required Map<String, dynamic> userInput})

Properties

argrument → String?
Gets the arguments associated with a toast action initiated by the user. This arguments string was included in the toast's XML payload.
final
eventType → EventType
event type
final
hashCode → int
The hash code for this object.
no setterinherited
message → NotificationMessage
notification messaage was send
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInput → Map<String, dynamic>
For toast notifications that include text boxes for user input, contains the user input.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited