WindowsNotificationPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • WindowsNotificationPlatform
Implementers

Constructors

WindowsNotificationPlatform()
Constructs a WindowsNotificationPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearNotificationHistory(String? applicationId) → Future<void>
init() → Future<void>
initNotificationCallBack(OnTapNotification? callback) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeNotification(String id, String group, String? applicationId) → Future<void>
removeNotificationGroup(String group, String? applicationId) → Future<void>
showNotification(NotificationMessage notification, String? applicationId) → Future<void>
showNotificationCustomTemplate(NotificationMessage notification, String? applicationId, String template) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ WindowsNotificationPlatform
The default instance of WindowsNotificationPlatform to use.
getter/setter pair